package betterquesting.client.gui2.editors.nbt;

import betterquesting.api.misc.ICallback;
import betterquesting.api.utils.BigItemStack;
import betterquesting.api.utils.JsonHelper;
import betterquesting.api.utils.NBTConverter;
import betterquesting.api2.client.gui.controls.PanelButtonStorage;
import betterquesting.api2.client.gui.controls.PanelTextField;
import betterquesting.api2.client.gui.controls.callbacks.CallbackMulti;
import betterquesting.api2.client.gui.controls.callbacks.CallbackNBTPrimitive;
import betterquesting.api2.client.gui.controls.callbacks.CallbackNBTTagString;
import betterquesting.api2.client.gui.controls.filters.FieldFilterNumber;
import betterquesting.api2.client.gui.controls.filters.FieldFilterString;
import betterquesting.api2.client.gui.events.IPEventListener;
import betterquesting.api2.client.gui.events.PEventBroadcaster;
import betterquesting.api2.client.gui.events.PanelEvent;
import betterquesting.api2.client.gui.events.types.PEventButton;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.panels.content.PanelGeneric;
import betterquesting.api2.client.gui.panels.content.PanelTextBox;
import betterquesting.api2.client.gui.panels.lists.CanvasScrolling;
import betterquesting.api2.client.gui.resources.colors.GuiColorStatic;
import betterquesting.api2.client.gui.resources.textures.IGuiTexture;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.utils.QuestTranslation;
import betterquesting.client.gui2.editors.GuiTextEditor;
import betterquesting.client.gui2.editors.nbt.callback.NbtEntityCallback;
import betterquesting.client.gui2.editors.nbt.callback.NbtFluidCallback;
import betterquesting.client.gui2.editors.nbt.callback.NbtItemCallback;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import net.minecraft.client.Minecraft;
import net.minecraft.entity.Entity;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagByte;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.nbt.NBTTagString;
import net.minecraftforge.fluids.FluidStack;
import org.lwjgl.input.Keyboard;

/* loaded from: betterquesting_client_gui2_editors_nbt.jar:betterquesting/client/gui2/editors/nbt/PanelScrollingNBT.class */
public class PanelScrollingNBT extends CanvasScrolling implements IPEventListener {
    private NBTBase nbt;
    private final int btnEdit;
    private final int btnAdv;
    private final int btnInsert;
    private final int btnDelete;
    private final Minecraft mc;

    public PanelScrollingNBT(IGuiRect rect, NBTTagCompound tag, int btnEdit, int btnAdv, int btnInsert, int btnDelete) {
        this(rect, btnEdit, btnAdv, btnInsert, btnDelete);
        setNBT(tag);
    }

    public PanelScrollingNBT(IGuiRect rect, NBTTagList tag, int btnEdit, int btnAdv, int btnInsert, int btnDelete) {
        this(rect, btnEdit, btnAdv, btnInsert, btnDelete);
        setNBT(tag);
    }

    private PanelScrollingNBT(IGuiRect rect, int btnEdit, int btnAdv, int btnInsert, int btnDelete) {
        super(rect);
        this.mc = Minecraft.func_71410_x();
        this.btnEdit = btnEdit;
        this.btnAdv = btnAdv;
        this.btnInsert = btnInsert;
        this.btnDelete = btnDelete;
        PEventBroadcaster.INSTANCE.register(this, PEventButton.class);
        Keyboard.enableRepeatEvents(true);
    }

    public PanelScrollingNBT setNBT(NBTTagCompound tag) {
        this.nbt = tag;
        refreshList();
        return this;
    }

    public PanelScrollingNBT setNBT(NBTTagList list) {
        this.nbt = list;
        refreshList();
        return this;
    }

    public void initPanel() {
        super.initPanel();
        refreshList();
    }

    private void refreshList() {
        resetCanvas();
        if (this.nbt == null) {
            return;
        }
        int preSX = getScrollX();
        int preSY = getScrollY();
        int width = getTransform().getWidth();
        int lw = (int) (width / 3.0f);
        int rw = width - lw;
        if (this.nbt.func_74732_a() == 10) {
            NBTTagCompound tag = this.nbt;
            List<String> sortedKeys = new ArrayList<>(tag.func_150296_c());
            Collections.sort(sortedKeys);
            int i = 0;
            for (String k : sortedKeys) {
                NBTTagString func_74781_a = tag.func_74781_a(k);
                PanelTextBox name = new PanelTextBox(new GuiRectangle(0, (i * 16) + 4, lw - 8, 12, 0), k).setAlignment(2);
                name.setColor(PresetColor.TEXT_MAIN.getColor());
                addPanel(name);
                if (func_74781_a.func_74732_a() == 10) {
                    addPanel(new PanelButtonStorage<>(new GuiRectangle(lw, i * 16, rw - 48, 16, 0), this.btnEdit, getButtonTitle((NBTTagCompound) func_74781_a), k));
                    addPanel(new PanelButtonStorage<>(new GuiRectangle(width - 48, i * 16, 16, 16, 0), this.btnAdv, "...", k));
                } else if (func_74781_a.func_74732_a() == 9) {
                    addPanel(new PanelButtonStorage<>(new GuiRectangle(lw, i * 16, rw - 32, 16, 0), this.btnEdit, "List...", k));
                } else if (func_74781_a.func_74732_a() == 8) {
                    PanelTextField<String> text = new PanelTextField<>(new GuiRectangle(lw, i * 16, rw - 48, 16, 0), "" + func_74781_a.func_150285_a_(), FieldFilterString.INSTANCE);
                    text.setCallback(new CallbackNBTTagString(tag, k)).setMaxLength(Integer.MAX_VALUE);
                    addPanel(text);
                    addPanel(new PanelButtonStorage<>(new GuiRectangle(width - 48, i * 16, 16, 16, 0), this.btnEdit, "Aa", k));
                } else if (func_74781_a.func_74732_a() == 1) {
                    PanelTextField<Byte> text2 = new PanelTextField<>(new GuiRectangle(lw, i * 16, rw / 2, 16, 0), "" + ((int) ((NBTBase.NBTPrimitive) func_74781_a).func_150290_f()), FieldFilterNumber.BYTE);
                    text2.setMaxLength(Integer.MAX_VALUE);
                    addPanel(text2);
                    PanelButtonStorage<String> btn = new PanelButtonStorage<>(new GuiRectangle(lw + (rw / 2), i * 16, ((int) Math.ceil(rw / 2.0f)) - 32, 16, 0), this.btnEdit, ((NBTBase.NBTPrimitive) func_74781_a).func_150290_f() > 0 ? "true" : "false", k);
                    addPanel(btn);
                    text2.setMaxLength(Integer.MAX_VALUE).setCallback(new CallbackMulti(new ICallback[]{new CallbackNBTPrimitive(tag, k, Byte.class), value -> {
                        btn.setText(value.byteValue() > 0 ? "true" : "false");
                    }}));
                    btn.setCallback(value2 -> {
                        boolean flag = tag.func_74771_c(value2) > 0;
                        tag.func_74774_a(value2, flag ? (byte) 0 : (byte) 1);
                        text2.setText(flag ? "0" : "1");
                        btn.setText(flag ? "false" : "true");
                    });
                } else if (func_74781_a.func_74732_a() > 1 && func_74781_a.func_74732_a() < 7) {
                    switch (func_74781_a.func_74732_a()) {
                        case 2:
                            PanelTextField<Short> text3 = new PanelTextField<>(new GuiRectangle(lw, i * 16, rw - 32, 16, 0), "" + ((int) ((NBTBase.NBTPrimitive) func_74781_a).func_150289_e()), FieldFilterNumber.SHORT);
                            text3.setCallback(new CallbackNBTPrimitive(tag, k, Short.class)).setMaxLength(Integer.MAX_VALUE);
                            addPanel(text3);
                            break;
                        case 3:
                            PanelTextField<Integer> text4 = new PanelTextField<>(new GuiRectangle(lw, i * 16, rw - 32, 16, 0), "" + ((NBTBase.NBTPrimitive) func_74781_a).func_150287_d(), FieldFilterNumber.INT);
                            text4.setCallback(new CallbackNBTPrimitive(tag, k, Integer.class)).setMaxLength(Integer.MAX_VALUE);
                            addPanel(text4);
                            break;
                        case 4:
                            PanelTextField<Long> text5 = new PanelTextField<>(new GuiRectangle(lw, i * 16, rw - 32, 16, 0), "" + ((NBTBase.NBTPrimitive) func_74781_a).func_150291_c(), FieldFilterNumber.LONG);
                            text5.setCallback(new CallbackNBTPrimitive(tag, k, Long.class)).setMaxLength(Integer.MAX_VALUE);
                            addPanel(text5);
                            break;
                        case 5:
                            PanelTextField<Float> text6 = new PanelTextField<>(new GuiRectangle(lw, i * 16, rw - 32, 16, 0), "" + ((NBTBase.NBTPrimitive) func_74781_a).func_150288_h(), FieldFilterNumber.FLOAT);
                            text6.setCallback(new CallbackNBTPrimitive(tag, k, Float.class)).setMaxLength(Integer.MAX_VALUE);
                            addPanel(text6);
                            break;
                        case 6:
                            PanelTextField<Double> text7 = new PanelTextField<>(new GuiRectangle(lw, i * 16, rw - 32, 16, 0), "" + ((NBTBase.NBTPrimitive) func_74781_a).func_150286_g(), FieldFilterNumber.DOUBLE);
                            text7.setCallback(new CallbackNBTPrimitive(tag, k, Double.class)).setMaxLength(Integer.MAX_VALUE);
                            addPanel(text7);
                            break;
                    }
                } else {
                    PanelTextBox err = new PanelTextBox(new GuiRectangle(lw, (i * 16) + 4, rw - 48, 12, 0), func_74781_a.getClass().getSimpleName() + " Not Supported Yet").setAlignment(1);
                    err.setColor(PresetColor.TEXT_MAIN.getColor());
                    addPanel(err);
                }
                PanelButtonStorage<String> btnI = new PanelButtonStorage<>(new GuiRectangle(width - 32, i * 16, 16, 16, 0), this.btnInsert, "+", k);
                btnI.setTextHighlight(new GuiColorStatic(128, 128, 128, 255), new GuiColorStatic(0, 255, 0, 255), new GuiColorStatic(0, 255, 0, 255));
                addPanel(btnI);
                PanelButtonStorage<String> btnD = new PanelButtonStorage<>(new GuiRectangle(width - 16, i * 16, 16, 16, 0), this.btnDelete, "x", k);
                btnD.setTextHighlight(new GuiColorStatic(128, 128, 128, 255), new GuiColorStatic(255, 0, 0, 255), new GuiColorStatic(255, 0, 0, 255));
                addPanel(btnD);
                i++;
            }
            addPanel(new PanelGeneric(new GuiRectangle(0, i * 16, width - 32, 16, 0), (IGuiTexture) null));
            PanelButtonStorage<String> btnI2 = new PanelButtonStorage<>(new GuiRectangle(width - 32, i * 16, 16, 16, 0), this.btnInsert, "+", "");
            btnI2.setTextHighlight(new GuiColorStatic(128, 128, 128, 255), new GuiColorStatic(0, 255, 0, 255), new GuiColorStatic(0, 255, 0, 255));
            addPanel(btnI2);
        } else if (this.nbt.func_74732_a() == 9) {
            NBTTagList list = this.nbt;
            int i2 = 0;
            List<NBTBase> tagList = NBTConverter.getTagList(list);
            while (i2 < tagList.size()) {
                NBTBase nBTBase = tagList.get(i2);
                PanelTextBox name2 = new PanelTextBox(new GuiRectangle(0, (i2 * 16) + 4, lw - 8, 16, 0), "#" + i2).setAlignment(2);
                name2.setColor(PresetColor.TEXT_MAIN.getColor());
                addPanel(name2);
                if (nBTBase.func_74732_a() == 10) {
                    addPanel(new PanelButtonStorage<>(new GuiRectangle(lw, i2 * 16, rw - 48, 16, 0), this.btnEdit, getButtonTitle((NBTTagCompound) nBTBase), Integer.valueOf(i2)));
                    addPanel(new PanelButtonStorage<>(new GuiRectangle(width - 48, i2 * 16, 16, 16, 0), this.btnAdv, "...", Integer.valueOf(i2)));
                } else if (nBTBase.func_74732_a() == 9) {
                    addPanel(new PanelButtonStorage<>(new GuiRectangle(lw, i2 * 16, rw - 32, 16, 0), this.btnEdit, "List...", Integer.valueOf(i2)));
                } else if (nBTBase.func_74732_a() == 8) {
                    PanelTextField<String> text8 = new PanelTextField<>(new GuiRectangle(lw, i2 * 16, rw - 48, 16, 0), "" + ((NBTTagString) nBTBase).func_150285_a_(), FieldFilterString.INSTANCE);
                    text8.setCallback(new CallbackNBTTagString(list, i2)).setMaxLength(Integer.MAX_VALUE);
                    addPanel(text8);
                    addPanel(new PanelButtonStorage<>(new GuiRectangle(width - 48, i2 * 16, 16, 16, 0), this.btnEdit, "Aa", Integer.valueOf(i2)));
                } else if (nBTBase.func_74732_a() == 1) {
                    PanelTextField<Byte> text9 = new PanelTextField<>(new GuiRectangle(lw, i2 * 16, rw / 2, 16, 0), "" + ((int) ((NBTBase.NBTPrimitive) nBTBase).func_150290_f()), FieldFilterNumber.BYTE);
                    addPanel(text9);
                    PanelButtonStorage<Integer> btn2 = new PanelButtonStorage<>(new GuiRectangle(lw + (rw / 2), i2 * 16, ((int) Math.ceil(rw / 2.0f)) - 32, 16, 0), this.btnEdit, ((NBTBase.NBTPrimitive) nBTBase).func_150290_f() > 0 ? "true" : "false", Integer.valueOf(i2));
                    addPanel(btn2);
                    text9.setMaxLength(Integer.MAX_VALUE).setCallback(new CallbackMulti(new ICallback[]{new CallbackNBTPrimitive(list, i2, Byte.class), value3 -> {
                        btn2.setText(value3.byteValue() > 0 ? "true" : "false");
                    }}));
                    btn2.setCallback(value4 -> {
                        boolean flag = ((NBTTagByte) tagList.get(value4.intValue())).func_150290_f() > 0;
                        list.func_150304_a(value4.intValue(), new NBTTagByte(flag ? (byte) 0 : (byte) 1));
                        text9.setText(flag ? "0" : "1");
                        btn2.setText(flag ? "false" : "true");
                    });
                } else if (nBTBase.func_74732_a() > 1 && nBTBase.func_74732_a() < 7) {
                    switch (nBTBase.func_74732_a()) {
                        case 2:
                            PanelTextField<Short> text10 = new PanelTextField<>(new GuiRectangle(lw, i2 * 16, rw - 32, 16, 0), "" + ((int) ((NBTBase.NBTPrimitive) nBTBase).func_150289_e()), FieldFilterNumber.SHORT);
                            text10.setCallback(new CallbackNBTPrimitive(list, i2, Short.class)).setMaxLength(Integer.MAX_VALUE);
                            addPanel(text10);
                            break;
                        case 3:
                            PanelTextField<Integer> text11 = new PanelTextField<>(new GuiRectangle(lw, i2 * 16, rw - 32, 16, 0), "" + ((NBTBase.NBTPrimitive) nBTBase).func_150287_d(), FieldFilterNumber.INT);
                            text11.setCallback(new CallbackNBTPrimitive(list, i2, Integer.class)).setMaxLength(Integer.MAX_VALUE);
                            addPanel(text11);
                            break;
                        case 4:
                            PanelTextField<Long> text12 = new PanelTextField<>(new GuiRectangle(lw, i2 * 16, rw - 32, 16, 0), "" + ((NBTBase.NBTPrimitive) nBTBase).func_150291_c(), FieldFilterNumber.LONG);
                            text12.setCallback(new CallbackNBTPrimitive(list, i2, Long.class)).setMaxLength(Integer.MAX_VALUE);
                            addPanel(text12);
                            break;
                        case 5:
                            PanelTextField<Float> text13 = new PanelTextField<>(new GuiRectangle(lw, i2 * 16, rw - 32, 16, 0), "" + ((NBTBase.NBTPrimitive) nBTBase).func_150288_h(), FieldFilterNumber.FLOAT);
                            text13.setCallback(new CallbackNBTPrimitive(list, i2, Float.class)).setMaxLength(Integer.MAX_VALUE);
                            addPanel(text13);
                            break;
                        case 6:
                            PanelTextField<Double> text14 = new PanelTextField<>(new GuiRectangle(lw, i2 * 16, rw - 32, 16, 0), "" + ((NBTBase.NBTPrimitive) nBTBase).func_150286_g(), FieldFilterNumber.DOUBLE);
                            text14.setCallback(new CallbackNBTPrimitive(list, i2, Double.class)).setMaxLength(Integer.MAX_VALUE);
                            addPanel(text14);
                            break;
                    }
                } else {
                    PanelTextBox err2 = new PanelTextBox(new GuiRectangle(lw, (i2 * 16) + 4, rw - 48, 12, 0), nBTBase.getClass().getSimpleName() + " Not Supported Yet").setAlignment(1);
                    err2.setColor(PresetColor.TEXT_MAIN.getColor());
                    addPanel(err2);
                }
                PanelButtonStorage<Integer> btnI3 = new PanelButtonStorage<>(new GuiRectangle(width - 32, i2 * 16, 16, 16, 0), this.btnInsert, "+", Integer.valueOf(i2));
                btnI3.setTextHighlight(new GuiColorStatic(128, 128, 128, 255), new GuiColorStatic(0, 255, 0, 255), new GuiColorStatic(0, 255, 0, 255));
                addPanel(btnI3);
                PanelButtonStorage<Integer> btnD2 = new PanelButtonStorage<>(new GuiRectangle(width - 16, i2 * 16, 16, 16, 0), this.btnDelete, "x", Integer.valueOf(i2));
                btnD2.setTextHighlight(new GuiColorStatic(128, 128, 128, 255), new GuiColorStatic(255, 0, 0, 255), new GuiColorStatic(255, 0, 0, 255));
                addPanel(btnD2);
                i2++;
            }
            addPanel(new PanelGeneric(new GuiRectangle(0, i2 * 16, width - 32, 16, 0), (IGuiTexture) null));
            PanelButtonStorage<Integer> btnI4 = new PanelButtonStorage<>(new GuiRectangle(width - 32, i2 * 16, 16, 16, 0), this.btnInsert, "+", Integer.valueOf(i2));
            btnI4.setTextHighlight(new GuiColorStatic(128, 128, 128, 255), new GuiColorStatic(0, 255, 0, 255), new GuiColorStatic(0, 255, 0, 255));
            addPanel(btnI4);
        }
        setScrollX(preSX);
        setScrollY(preSY);
    }

    public void onPanelEvent(PanelEvent event) {
        if (event instanceof PEventButton) {
            onButtonPress((PEventButton) event);
        }
    }

    private void onButtonPress(PEventButton event) {
        NBTBase entry;
        if (this.nbt == null) {
            return;
        }
        PanelButtonStorage button = event.getButton();
        Minecraft mc = Minecraft.func_71410_x();
        if (button.getButtonID() != this.btnEdit && button.getButtonID() != this.btnAdv && button.getButtonID() != this.btnInsert && button.getButtonID() != this.btnDelete) {
            return;
        }
        if (this.nbt.func_74732_a() == 10) {
            entry = this.nbt.func_74781_a((String) button.getStoredValue());
        } else if (this.nbt.func_74732_a() == 9) {
            List<NBTBase> tagList = NBTConverter.getTagList(this.nbt);
            int idx = ((Integer) button.getStoredValue()).intValue();
            entry = (idx < 0 || idx >= tagList.size()) ? null : tagList.get(idx);
        } else {
            throw new RuntimeException("Invalid NBT tag type!");
        }
        if (button.getButtonID() == this.btnEdit && entry != null) {
            if (entry.func_74732_a() == 10) {
                NBTTagCompound tag = (NBTTagCompound) entry;
                if (JsonHelper.isItem(tag)) {
                    mc.func_147108_a(new GuiItemSelection(mc.field_71462_r, tag, (ICallback<BigItemStack>) new NbtItemCallback(tag)));
                    return;
                }
                if (JsonHelper.isFluid(tag)) {
                    mc.func_147108_a(new GuiFluidSelection(mc.field_71462_r, tag, (ICallback<FluidStack>) new NbtFluidCallback(tag)));
                    return;
                } else if (JsonHelper.isEntity(tag)) {
                    mc.func_147108_a(new GuiEntitySelection(mc.field_71462_r, tag, (ICallback<Entity>) new NbtEntityCallback(tag)));
                    return;
                } else {
                    mc.func_147108_a(new GuiNbtEditor(mc.field_71462_r, tag, (ICallback<NBTTagCompound>) null));
                    return;
                }
            }
            if (entry.func_74732_a() == 9) {
                mc.func_147108_a(new GuiNbtEditor(mc.field_71462_r, (NBTTagList) entry, (ICallback<NBTTagList>) null));
                return;
            }
            if (entry.func_74732_a() == 8) {
                if (this.nbt.func_74732_a() == 10) {
                    mc.func_147108_a(new GuiTextEditor(mc.field_71462_r, ((NBTTagString) entry).func_150285_a_(), new CallbackNBTTagString(this.nbt, (String) button.getStoredValue())));
                    return;
                } else {
                    if (this.nbt.func_74732_a() == 9) {
                        mc.func_147108_a(new GuiTextEditor(mc.field_71462_r, ((NBTTagString) entry).func_150285_a_(), new CallbackNBTTagString(this.nbt, ((Integer) button.getStoredValue()).intValue())));
                        return;
                    }
                    return;
                }
            }
            if (entry.func_74732_a() == 7 || entry.func_74732_a() == 11 || entry.func_74732_a() == 12) {
                throw new UnsupportedOperationException("NBTTagByteArray, NBTTagIntArray and NBTTagLongArray are not currently supported yet");
            }
            return;
        }
        if (button.getButtonID() == this.btnAdv && entry != null) {
            if (entry.func_74732_a() == 10) {
                mc.func_147108_a(new GuiNbtType(mc.field_71462_r, (NBTTagCompound) entry));
                return;
            } else {
                if (entry.func_74732_a() == 9) {
                    mc.func_147108_a(new GuiNbtEditor(mc.field_71462_r, (NBTTagList) entry, (ICallback<NBTTagList>) null));
                    return;
                }
                return;
            }
        }
        if (button.getButtonID() == this.btnInsert) {
            if (this.nbt.func_74732_a() == 10) {
                mc.func_147108_a(new GuiNbtAdd(mc.field_71462_r, this.nbt));
                return;
            } else {
                if (this.nbt.func_74732_a() == 9) {
                    mc.func_147108_a(new GuiNbtAdd(mc.field_71462_r, this.nbt, ((Integer) button.getStoredValue()).intValue()));
                    return;
                }
                return;
            }
        }
        if (button.getButtonID() == this.btnDelete && entry != null) {
            if (this.nbt.func_74732_a() == 10) {
                this.nbt.func_82580_o((String) button.getStoredValue());
                refreshList();
            } else if (this.nbt.func_74732_a() == 9) {
                this.nbt.func_74744_a(((Integer) button.getStoredValue()).intValue());
                refreshList();
            }
        }
    }

    private String getButtonTitle(NBTTagCompound tag) {
        if (JsonHelper.isItem(tag)) {
            BigItemStack stack = JsonHelper.JsonToItemStack(tag);
            return QuestTranslation.translate("betterquesting.btn.item", new Object[0]) + ": " + (stack == null ? "NULL" : stack.getBaseStack().func_82833_r());
        }
        if (JsonHelper.isFluid(tag)) {
            FluidStack fluid = JsonHelper.JsonToFluidStack(tag);
            return QuestTranslation.translate("betterquesting.btn.fluid", new Object[0]) + ": " + fluid.getLocalizedName();
        }
        if (JsonHelper.isEntity(tag)) {
            Entity entity = JsonHelper.JsonToEntity(tag, this.mc.field_71441_e);
            return QuestTranslation.translate("betterquesting.btn.entity", new Object[0]) + ": " + entity.func_70005_c_();
        }
        return "Object...";
    }
}
